"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.listMessages = exports.bulkCreateMessages = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const timestamp_2 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveWixInnovationAssistantWidgetV1ChatWidgetUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        _: [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'editor.wixapps.net': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/wix-assistant-widget',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/assistant-widget_messages';
/**
 * Bulk creates messages.
 *
 * This method must be called using the site visitor or site member identity ([SDK](https://dev.wix.com/docs/sdk/articles/get-started/about-identities#site-member) | [REST](https://dev.wix.com/docs/rest/articles/getting-started/about-identities#site-member)) to identify the site visitor that is creating the messages. Therefore, [Wix apps](https://dev.wix.com/docs/build-apps) can't currently call this method using REST.
 */
function bulkCreateMessages(payload) {
    function __bulkCreateMessages({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'messages.createdDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.innovation.widget.v1.message',
            method: 'POST',
            methodFqn: 'wix.innovation.assistant.widget.v1.ChatWidget.BulkCreateMessages',
            packageName: PACKAGE_NAME,
            url: resolveWixInnovationAssistantWidgetV1ChatWidgetUrl({
                protoPath: '/v1/bulk/messages/create',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'messages.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __bulkCreateMessages;
}
exports.bulkCreateMessages = bulkCreateMessages;
/**
 * Retrieves a list of messages.
 *
 * Up to 100 Messages can be returned per request.
 *
 * This method must be called using the site visitor or site member identity ([SDK](https://dev.wix.com/docs/sdk/articles/get-started/about-identities#site-member) | [REST](https://dev.wix.com/docs/rest/articles/getting-started/about-identities#site-member)) to identify the site visitor that is retrieving the messages. Therefore, [Wix apps](https://dev.wix.com/docs/build-apps) can't currently call this method using REST.
 */
function listMessages(payload) {
    function __listMessages({ host }) {
        const metadata = {
            entityFqdn: 'wix.innovation.widget.v1.message',
            method: 'GET',
            methodFqn: 'wix.innovation.assistant.widget.v1.ChatWidget.ListMessages',
            packageName: PACKAGE_NAME,
            url: resolveWixInnovationAssistantWidgetV1ChatWidgetUrl({
                protoPath: '/v1/messages/list',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'messages.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __listMessages;
}
exports.listMessages = listMessages;
//# sourceMappingURL=innovation-widget-v1-message-messages.http.js.map