import { toURLSearchParams } from '@wix/sdk-runtime/rest-modules';
import { transformSDKTimestampToRESTTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { resolveUrl } from '@wix/sdk-runtime/rest-modules';
function resolveWixInnovationAssistantWidgetV1ChatWidgetUrl(opts) {
    const domainToMappings = {
        'manage._base_domain_': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        _: [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        '*.dev.wix-code.com': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'editor.wixapps.net': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/wix-assistant-widget',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/wix-assistant-widget',
                destPath: '',
            },
        ],
    };
    return resolveUrl(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/assistant-widget_messages';
/**
 * Bulk creates messages.
 *
 * This method must be called using the site visitor or site member identity ([SDK](https://dev.wix.com/docs/sdk/articles/get-started/about-identities#site-member) | [REST](https://dev.wix.com/docs/rest/articles/getting-started/about-identities#site-member)) to identify the site visitor that is creating the messages. Therefore, [Wix apps](https://dev.wix.com/docs/build-apps) can't currently call this method using REST.
 */
export function bulkCreateMessages(payload) {
    function __bulkCreateMessages({ host }) {
        const serializedData = transformPaths(payload, [
            {
                transformFn: transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'messages.createdDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.innovation.widget.v1.message',
            method: 'POST',
            methodFqn: 'wix.innovation.assistant.widget.v1.ChatWidget.BulkCreateMessages',
            packageName: PACKAGE_NAME,
            url: resolveWixInnovationAssistantWidgetV1ChatWidgetUrl({
                protoPath: '/v1/bulk/messages/create',
                data: serializedData,
                host,
            }),
            data: serializedData,
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'messages.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __bulkCreateMessages;
}
/**
 * Retrieves a list of messages.
 *
 * Up to 100 Messages can be returned per request.
 *
 * This method must be called using the site visitor or site member identity ([SDK](https://dev.wix.com/docs/sdk/articles/get-started/about-identities#site-member) | [REST](https://dev.wix.com/docs/rest/articles/getting-started/about-identities#site-member)) to identify the site visitor that is retrieving the messages. Therefore, [Wix apps](https://dev.wix.com/docs/build-apps) can't currently call this method using REST.
 */
export function listMessages(payload) {
    function __listMessages({ host }) {
        const metadata = {
            entityFqdn: 'wix.innovation.widget.v1.message',
            method: 'GET',
            methodFqn: 'wix.innovation.assistant.widget.v1.ChatWidget.ListMessages',
            packageName: PACKAGE_NAME,
            url: resolveWixInnovationAssistantWidgetV1ChatWidgetUrl({
                protoPath: '/v1/messages/list',
                data: payload,
                host,
            }),
            params: toURLSearchParams(payload),
            transformResponse: (payload) => transformPaths(payload, [
                {
                    transformFn: transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'messages.createdDate' }],
                },
            ]),
        };
        return metadata;
    }
    return __listMessages;
}
//# sourceMappingURL=innovation-widget-v1-message-messages.http.js.map